@@ -5,7 +5,7 @@ use strict;
 use 5.008;
 use List::MoreUtils qw(all mesh);
 
-our $VERSION = '0.99';
+our $VERSION = '1.00';
 
 # Public methods
 
@@ -238,7 +238,7 @@ Games::Sudoku::CPSearch - Solve Sudoku problems quickly.
 
 =head1 VERSION
 
-Version 0.99
+Version 1.00
 
 =cut
 
@@ -259,7 +259,7 @@ Version 0.99
     PUZZLE
 
     open FH, ">example.txt";
-    print FH, $puzzle;
+    print FH $puzzle;
     close FH;
 
     my $sudoku = Games::Sudoku::CPSearch->new("example.txt");
